#!/usr/bin/env node
"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));

// src/index.ts
var import_read_pkg = require("read-pkg");
var import_fs = __toESM(require("fs"));
var import_inquirer = __toESM(require("inquirer"));
var import_child_process = require("child_process");
function readPackageScripts() {
  try {
    const packageJson = (0, import_read_pkg.readPackageSync)();
    if (!packageJson) {
      console.log("No package.json found");
      process.exit(1);
    }
    ;
    if (!packageJson.scripts) {
      console.log("No scripts to read");
      process.exit(1);
    }
    ;
    return { scripts: Object.keys(packageJson.scripts), packageManager: detectPackageManager() };
  } catch (error) {
    console.error("Error occurred while reading package.json:", error);
    process.exit(1);
  }
}
function detectPackageManager() {
  if (import_fs.default.existsSync("yarn.lock")) {
    return "yarn";
  } else if (import_fs.default.existsSync("pnpm-lock.yaml")) {
    return "pnpm";
  } else if (import_fs.default.existsSync("rush.json")) {
    return "rush";
  } else {
    return "npm";
  }
}
function handleScriptExecution(scriptName, packageManager) {
  console.log(`Running script: ${scriptName}`);
  const command = `${packageManager} run ${scriptName}`;
  try {
    (0, import_child_process.execSync)(command, { stdio: "inherit" });
  } catch (error) {
    console.error(`Error occurred while running script ${scriptName}:`, error);
  }
}
function handleExit() {
  console.log("\n\nEsc key pressed. Exiting...");
  process.exit(0);
}
function main() {
  const { scripts, packageManager } = readPackageScripts();
  if (scripts.length === 0) {
    console.log("No scripts found in package.json. Exiting...");
    process.exit(1);
  }
  process.stdin.on("keypress", (ch, key) => {
    if (key && key.name === "escape") {
      handleExit();
    }
  });
  process.on("SIGINT", () => {
    console.log("\n\nScript interrupted by user. Exiting...");
    process.exit(0);
  });
  import_inquirer.default.prompt([
    {
      type: "list",
      name: "script",
      message: "Select a script to run:",
      choices: scripts
    }
  ]).then((answers) => {
    const scriptName = answers.script;
    handleScriptExecution(scriptName, packageManager);
  }).catch((error) => {
    console.error("Error occurred:", error);
  });
}
main();
